@@ -1,20 +1,15 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import json
 import os
 import shutil
-import six
-
 from contextlib import contextmanager
 
-from stone.ir import (
-    is_list_type,
-    is_numeric_type,
-    is_string_type,
-    is_struct_type,
-    is_union_type,
-    is_void_type,
-    unwrap_nullable,
+import six
+
+from stone.backends.swift import (
+    base,
+    fmt_serial_obj,
+    SwiftBaseBackend,
+    undocumented,
 )
 from stone.backends.swift_helpers import (
     check_route_name_conflict,
@@ -24,25 +19,21 @@ from stone.backends.swift_helpers import (
     fmt_var,
     fmt_type,
 )
-from stone.backends.swift import (
-    base,
-    fmt_serial_obj,
-    SwiftBaseBackend,
-    undocumented,
+from stone.ir import (
+    is_list_type,
+    is_numeric_type,
+    is_string_type,
+    is_struct_type,
+    is_union_type,
+    is_void_type,
+    unwrap_nullable,
 )
 
 _MYPY = False
 if _MYPY:
     import typing  # noqa: F401 # pylint: disable=import-error,unused-import,useless-suppression
 
-# Hack to get around some of Python 2's standard library modules that
-# accept ascii-encodable unicode literals in lieu of strs, but where
-# actually passing such literals results in errors with mypy --py2. See
-# <https://github.com/python/typeshed/issues/756> and
-# <https://github.com/python/mypy/issues/2536>.
-import importlib
-argparse = importlib.import_module(str('argparse'))  # type: typing.Any
-
+import argparse
 
 _cmdline_parser = argparse.ArgumentParser(prog='swift-types-backend')
 _cmdline_parser.add_argument(
@@ -236,8 +227,8 @@ class SwiftTypesBackend(SwiftBaseBackend):
             )
         elif is_string_type(data_type):
             pat = data_type.pattern if data_type.pattern else None
-            pat = pat.encode('unicode_escape').replace(six.ensure_binary("\""),
-                                                       six.ensure_binary("\\\"")) if pat else pat
+            pat = pat.encode('unicode_escape').replace(b"\"",
+                                                       b"\\\"") if pat else pat
             v = "stringValidator({})".format(
                 self._func_args([
                     ("minLength", data_type.min_length),
